@@ -251,7 +251,7 @@ public:
     //! Gets the direction of peak calculations.
     /*! \return The current direction of peak calculations.
      */
-    stf::direction GetDirection() const;
+    stfnum::direction GetDirection() const;
 
     //! Gets the mode of Latency for the beginning of the latency cursor.
     /*! \return The current mode for the beginning latency cursor.
@@ -304,7 +304,7 @@ public:
     //! Sets the direction of peak calculations.
     /*! \param direction The new direction of peak calculations.
      */
-    void SetDirection(stf::direction direction);
+    void SetDirection(stfnum::direction direction);
 
 #ifdef WITH_PSLOPE
     //! Sets the mode of the right slope cursor.
@@ -326,12 +326,12 @@ public:
     //! Sets the reference for baseline measurement.
     /*! \param median true if the median should be used, false if the average is used.
      */
-    void SetBaselineMethod(enum stf::baseline_method);
+    void SetBaselineMethod(enum stfnum::baseline_method);
 
     //! Indiates whether baseline is computed as mean or as median.
     /*! \param false indicates computing average (mean & s.d.), 1 indicates median & iqr.
      */
-    enum stf::baseline_method GetBaselineMethod() const;
+    enum stfnum::baseline_method GetBaselineMethod() const;
 
     //! Indicates whether the right peak cursor should always be at the end of the trace.
     /*! \return true if the peak cursor should always be at the end of the trace.
