@@ -693,79 +693,6 @@ public:
 
 class wxDirPickerCtrl;
 
-//! Dialog for batch conversion of files.from cfs to atf.
-class wxStfConvertDlg : public wxDialog 
-{
-    DECLARE_EVENT_TABLE()
-
-private:
-    wxGenericDirCtrl *mySrcDirCtrl, *myDestDirCtrl; 
-    wxString srcDir,destDir;
-    wxString srcFilter;
-
-    stfio::filetype srcFilterExt, destFilterExt;
-    std::vector<wxString> srcFileNames;
-
-    bool ReadPath(const wxString& path);
-
-    void OnComboBoxSrcExt(wxCommandEvent& event);
-    void OnComboBoxDestExt(wxCommandEvent& event);
-
-    //! Only called when a modal dialog is closed with the OK button.
-    /*! \return true if all dialog entries could be read successfully
-     */
-    bool OnOK();
-
-public:
-    //! Constructor
-    /*! \param parent Pointer to parent window.
-     *  \param id Window id.
-     *  \param title Dialog title.
-     *  \param pos Initial position.
-     *  \param size Initial size.
-     *  \param style Dialog style.
-     */
-    wxStfConvertDlg( wxWindow* parent, int id = wxID_ANY, wxString title = wxT("Convert file series"),
-            wxPoint pos = wxDefaultPosition, wxSize size = wxDefaultSize, int style = wxCAPTION );
-
-    //! Get the source directory.
-    /*! \return The source directory.
-     */
-    wxString GetSrcDir() const {return srcDir;}
-
-    //! Get the destination directory.
-    /*! \return The destination directory.
-     */
-    wxString GetDestDir() const {return destDir;}
-
-    //! Get the source extension filter.
-    /*! \return The source extension filter.
-     */
-    wxString GetSrcFilter() const {return srcFilter;}
-
-    //! Get the source extension as stfio::filetype.
-    /*! \return The source extension as stfio::filetype.
-     */
-    stfio::filetype GetSrcFileExt() const {return srcFilterExt;}
-
-    //! Get the destination extension as stfio::filetype.
-    /*! \return The destination extension as stfio::filetype.
-     */
-    stfio::filetype GetDestFileExt() const {return destFilterExt;}
-
-    //! Get the list of file names.
-    /*! \return A vector with source file names.
-     */
-    std::vector<wxString> GetSrcFileNames() const {return srcFileNames;}
-    
-    //! Called upon ending a modal dialog.
-    /*! \param retCode The dialog button id that ended the dialog
-     *         (e.g. wxID_OK)
-     */
-    virtual void EndModal(int retCode);
-
-};
-
 class wxListCtrl;
 
 //! Dialog for re-ordering channels before saving to file
