@@ -58,6 +58,7 @@
 #include "./graph.h"
 #include "./table.h"
 #include "./printout.h"
+#include "./dlgs/convertdlg.h"
 #include "./dlgs/smalldlgs.h"
 #include "./copygrid.h"
 #include "./../../libstfio/atf/atflib.h"
@@ -104,6 +105,10 @@
 #include "./../res/slope.xpm"
 #endif
 
+#ifndef wxS_DIR_DEFAULT
+#define wxS_DIR_DEFAULT 0777
+#endif
+
 IMPLEMENT_CLASS(wxStfParentFrame, wxStfParentType)
 BEGIN_EVENT_TABLE(wxStfParentFrame, wxStfParentType)
 EVT_MENU(wxID_HELP, wxStfParentFrame::OnHelp)
@@ -744,24 +749,31 @@ void wxStfParentFrame::OnConvert(wxCommandEvent& WXUNUSED(event) ) {
         wxProgressDialog progDlg( wxT("CFS conversion utility"), wxT("Starting file conversion"),
             100, NULL, wxPD_SMOOTH | wxPD_AUTO_HIDE | wxPD_APP_MODAL );
 
-        std::vector<wxString> srcFilenames(myDlg.GetSrcFileNames());
+        wxArrayString srcFilenames(myDlg.GetSrcFileNames());
         nfiles = srcFilenames.size(); // number of files to convert
         wxString myDestDir = myDlg.GetDestDir();
-        std::cout << myDestDir.c_str() << std::endl;
 
         for (std::size_t nFile=0; nFile<srcFilenames.size(); ++nFile) {
             wxString progStr;
 
-            // construct new filename:
+            // Strip source directory from source file name:
             wxFileName srcWxFilename(srcFilenames[nFile]);
-            wxString destFilename(
-                                  myDlg.GetDestDir()+
-                                  wxFileName::GetPathSeparators(wxPATH_NATIVE)+
-                                  srcWxFilename.GetName()  // returns file name without path and extension
-                                  );
+            srcWxFilename.MakeRelativeTo(myDlg.GetSrcDir());
+            srcWxFilename.ClearExt();
+            wxString destFilename(myDlg.GetDestDir() +
+                                  wxFileName::GetPathSeparators(wxPATH_NATIVE) +
+                                  srcWxFilename.GetFullPath() +
+                                  stf::std2wx(stfio::findExtension(myDlg.GetDestFileExt())));
+
+            wxString target_path = wxFileName(destFilename).GetPath();
+            if (!wxFileName::DirExists(target_path)) {
+                wxFileName::Mkdir(target_path, wxS_DIR_DEFAULT, wxPATH_MKDIR_FULL);
+            }
+
             if ( eft == stfio::atf ) {
                 destFilename += wxT(".atf");
             }
+
             // Update progress bar:
             progStr << wxT("Converting file #") << (int)nFile + 1
                 << wxT(" of ") << (int)srcFilenames.size() << wxT("\n")
