@@ -151,9 +151,6 @@ extern double _figsize[];
 #ifdef WITH_PYTHON
 PyObject* mpl_panel(const std::vector<double>& figsize = std::vector<double>(_figsize, _figsize+2));
 
-PyObject* detect_events(double* invec, int size, const std::string& mode="criterion",
-                        bool norm=true, double lowpass=0.5, double highpass=0.0001);
-PyObject* peak_detection(double* invec, int size, double threshold, int min_distance);
 #endif
  
 #endif
